@@ -15,7 +15,7 @@ fixest_env <- function(fml, data, family=c("poisson", "negbin", "logit", "gaussi
                        verbose = 0, theta.init, fixef.tol = 1e-5, fixef.iter = 10000,
                        deriv.iter = 5000, deriv.tol = 1e-4, glm.iter = 25, glm.tol = 1e-8,
                        etastart, mustart,
-                       warn = TRUE, notes = getFixest_notes(), combine.quick,
+                       warn = TRUE, notes = getFixest_notes(), combine.quick, demeaned = FALSE,
                        origin_bis, origin = "feNmlm", mc_origin, mc_origin_bis, mc_origin_ter,
                        computeModel0 = FALSE, weights,
                        from_update = FALSE, object, sumFE_init, debug = FALSE, ...){
@@ -62,7 +62,7 @@ fixest_env <- function(fml, data, family=c("poisson", "negbin", "logit", "gaussi
     femlm_args = c("family", "theta.init", "linear.start", "opt.control", "deriv.tol", "deriv.iter")
     feNmlm_args = c("NL.fml", "NL.start", "lower", "upper", "NL.start.init", "jacobian.method", "useHessian", "hessian.args")
     feglm_args = c("family", "weights", "glm.iter", "glm.tol", "etastart", "mustart")
-    feols_args = c("weights")
+    feols_args = c("weights", "demeaned")
     internal_args = c("debug", "object", "from_update", "sumFE_init")
 
     deprec_old_new = c()
@@ -218,21 +218,11 @@ fixest_env <- function(fml, data, family=c("poisson", "negbin", "logit", "gaussi
         computeModel0 = family_equiv %in% c("poisson", "logit")
     }
 
-    if(!isLogical(notes)){
-        stop("Argument 'notes' must be a single logical.")
-    }
+    check_arg(demeaned, notes, warn, na_inf.rm, "logical scalar")
 
     show_notes = notes
     notes = c()
 
-    if(!isLogical(warn)){
-        stop("Argument 'warn' must be a single logical.")
-    }
-
-    if(!isLogical(na_inf.rm)){
-        stop("Argument 'na_inf.rm' must be a single logical.")
-    }
-
     # flags for NA infinite vales => will be used in the message (good to discrimintae b/w NA and inf)
     ANY_INF = FALSE
     ANY_NA = FALSE
@@ -278,7 +268,10 @@ fixest_env <- function(fml, data, family=c("poisson", "negbin", "logit", "gaussi
 
         #
         # The data
+
         if(missing(data)) stop("You must provide the argument 'data' (currently it is missing).")
+        check_value(data, "matrix | data.frame", .arg_name = "data")
+
         if(is.matrix(data)){
             if(is.null(colnames(data))){
                 stop("If argument data is to be a matrix, its columns must be named.")
@@ -300,9 +293,11 @@ fixest_env <- function(fml, data, family=c("poisson", "negbin", "logit", "gaussi
         #
         # The fml => controls + setup
         if(missing(fml)) stop("You must provide the argument 'fml' (currently it is missing).")
+        check_value(fml, "ts formula", .arg_name = "fml")
+
         if(!"formula" %in% class(fml)) stop("The argument 'fml' must be a formula.")
         fml = formula(fml) # we regularize the formula to check it
-        if(length(fml) != 3) stop("The formula must be two sided: e.g. y~x1+x2, or y~x1+x2|fe1+fe2.")
+        # if(length(fml) != 3) stop("The formula must be two sided: e.g. y~x1+x2, or y~x1+x2|fe1+fe2.")
 
         # We apply expand for macros => we return fml_no_xpd
         if(length(getFixest_fml()) > 0){
@@ -1124,6 +1119,7 @@ fixest_env <- function(fml, data, family=c("poisson", "negbin", "logit", "gaussi
 
             } else {
                 # If na_inf.rm => we keep track of the NAs
+                ANY_NA = TRUE
                 anyNA_sample = TRUE
                 isNA_sample = isNA_sample | isNA_fixef
                 msgNA_fixef = paste0(", Fixed-effects: ", numberFormatNormal(sum(isNA_fixef)))
